@@ -52,6 +52,7 @@
 #include <config.h>
 #endif
 
+#define FIX_1400
 
 #include "XmI.h"
 #include "ColorObjI.h"
@@ -59,6 +60,9 @@
 #include "CallbackI.h"
 #include "ColorI.h"
 #include "MessagesI.h"
+#ifdef FIX_1400
+#include <X11/Xlibint.h>
+#endif
 
 #if defined(__cplusplus) || defined(c_plusplus)
 #define  OBJ_CLASS(w)   (((ApplicationShellWidget)(w))->application.c_class)
@@ -69,6 +73,10 @@
 #define WARNING1	_XmMMsgColObj_0001
 #define WARNING2	_XmMMsgColObj_0002
 
+#ifdef FIX_1400
+static void trap_XCloseDisplay(Display *disp, XExtCodes *codes);
+#endif
+
 /** default should not be killed unless application is dying **/
 externaldef (colorobj) XmColorObj _XmDefaultColorObj = NULL;
 externaldef (colorobj) XContext _XmColorObjCache = 0;
@@ -418,6 +426,9 @@ Initialize(
     /* window id of the selection owner */
     Window SelectionOwner ;
     int result, isNotNews ;
+#ifdef FIX_1400
+    XExtCodes *xExt;
+#endif
 
     /* Ideally, we'd like check if we have a visual (like TrueColor)
        or colormap (non default) that would invalidate the use of
@@ -442,8 +453,16 @@ Initialize(
     _XmProcessLock();
     if (!_XmColorObjCache) _XmColorObjCache = XUniqueContext();
 
+#ifdef FIX_1400
+    if (_XmColorObjCacheDisplay == NULL) {
+        _XmColorObjCacheDisplay = new_obj->color_obj.display;
+        xExt = XAddExtension(_XmColorObjCacheDisplay);
+        XESetCloseDisplay(_XmColorObjCacheDisplay, xExt->extension, trap_XCloseDisplay);
+    }
+#else
     if (_XmColorObjCacheDisplay == NULL)
         _XmColorObjCacheDisplay = new_obj->color_obj.display;
+#endif
 
     if (_XmDefaultColorObj == NULL)
         _XmDefaultColorObj = new_obj;
@@ -1532,3 +1551,10 @@ XmeGetDesktopColorCells (Screen * screen,
 	return True;
 }
 
+#ifdef FIX_1400
+static void trap_XCloseDisplay(Display *disp, XExtCodes *codes)
+{
+    if (disp == _XmColorObjCacheDisplay)
+    	_XmColorObjCacheDisplay = NULL;
+}
+#endif
