@@ -67,7 +67,12 @@
 		 ButtonPressMask | ButtonReleaseMask)
 
 /********    Static Function Declarations    ********/
-
+#ifdef FIX_1445
+static void MouseWheel (Widget grabshell,
+		     XEvent *event,
+		     String *params,
+		     Cardinal *num_params);
+#endif
 static void BtnUp (Widget grabshell,
 		     XEvent *event,
 		     String *params,
@@ -114,6 +119,10 @@ static XtActionsRec actionsList[] =
   { "GrabShellBtnDown", BtnDown },
   { "GrabShellBtnUp",   BtnUp },
   { "GrabShellPopdown", Popdown }
+#ifdef FIX_1445
+  ,
+  { "GrabShellMouseWheel", MouseWheel }
+#endif
 };
 
 
@@ -404,6 +413,14 @@ MapNotifyHandler(Widget shell, XtPointer client_data,
   XSetErrorHandler(old_handler);
 }
 
+#ifdef FIX_1445
+static void MouseWheel (Widget w, XEvent *event, String *params, Cardinal *num_params)
+{
+	XmGrabShellWidget grabshell = (XmGrabShellWidget) w;
+	GSAllowEvents(w, SyncPointer, event -> xbutton.time);
+}
+#endif
+
 /* 
  * For BtnUp and BtnDown events we need to decide whether to
  * popdown the grabshell.  We "see" these if the user presses
@@ -429,11 +446,7 @@ BtnUp (Widget w,
      we then ignore the event if it occured within the 
      click to post time */
   delta = event -> xbutton.time - grabshell -> grab_shell.post_time;
-#ifdef XSETTINS_ON
-	if (delta <= XmeGetMultiClickTime(XtDisplay(w))) {
-#else 
   if (delta <= XtGetMultiClickTime(XtDisplay(w))) {
-#endif
     GSAllowEvents(w, SyncPointer, event -> xbutton.time);
     return;
   }
