@@ -86,8 +86,13 @@ static char rcsid[] = "$TOG: Label.c /main/26 1997/06/18 17:40:00 samborn $"
 #include "XmStringI.h"
 #include <Xm/XpmP.h>
 #include <string.h>
+#include <Xm/XmP.h>
+#ifdef FIX_1381
+#include <Xm/ColorI.h>
+#endif
 
 #define FIX_1442
+#define FIX_1484
 
 #define Pix(w)			((w)->label.pixmap)
 #define Pix_insen(w)		((w)->label.pixmap_insen)
@@ -149,10 +154,6 @@ static char* GetLabelAccelerator(Widget);
 static KeySym GetLabelMnemonic(Widget);
 static XtPointer ConvertToEncoding(Widget, char*, Atom, unsigned long *, 
 				 Boolean *);
-#ifdef FIX_1381
-static Pixmap ConvertToBW(Widget w, Pixmap pm);
-static unsigned int FromColorToBlackAndWhite(char *col);
-#endif
 /********    End Static Function Declarations    ********/
 
 
@@ -697,7 +698,7 @@ SetNormalGC(XmLabelWidget lw)
 				     dynamicMask, 0);
   
 #ifdef FIX_1381
-/*added for gray insensitive foreground (instead stipple)*/
+  /*generally gray insensitive foreground (instead stipple)*/
   values.foreground =  _XmAssignInsensitiveColor((Widget)lw);
   values.background = lw->core.background_pixel;
 #else
@@ -710,6 +711,13 @@ SetNormalGC(XmLabelWidget lw)
   
   lw->label.insensitive_GC = XtAllocateGC((Widget) lw, 0, valueMask, &values,
 					  dynamicMask, 0);
+#ifdef FIX_1381
+  /*light shadow for insensitive text (instead stipple)*/
+  values.foreground = lw->primitive.top_shadow_color;
+  lw->label.shadow_GC = XtAllocateGC((Widget) lw, 0, valueMask, &values,
+					  dynamicMask, 0);
+#endif
+
 }
 
 /************************************************************************
@@ -1380,84 +1388,10 @@ Destroy(
 
   XtReleaseGC ((Widget) lw, lw->label.normal_GC);
   XtReleaseGC ((Widget) lw, lw->label.insensitive_GC);
-}
-
 #ifdef FIX_1381
-static
-unsigned int
-FromColorToBlackAndWhite (char *col)
-{
-    unsigned long r, g, b, bw;
-    char k[5];
-    k[4] = '\0';
-    
-    memcpy(k, col, 4);
-    r = strtoul(k, NULL, 16);
-    memcpy(k, col + 4, 4);
-    g = strtoul(k, NULL, 16);
-    b = strtoul(col + 8, NULL, 16);
-    bw = (0.3 * r + 0.59 * g + 0.11 * b);
-    return (bw);
-}
-
-static
-Pixmap ConvertToBW(Widget w, Pixmap pm)
-{
-    Pixmap bw_pixmap;
-    XpmImage im;
-    int i = 0;
-    unsigned int bw = 0, bw2 = 0;
-    char *col = NULL, *col2 = NULL;
-    
-    XpmCreateXpmImageFromPixmap(XtDisplay(w), pm, 0, &im, NULL);
-    if (im.ncolors > 0)	{
-	if (im.ncolors <= 2) {
-	    if (im.ncolors == 1) {
-		col = strdup(im.colorTable[0].c_color);
-		if (col[0] == '#') {
-		    bw = (FromColorToBlackAndWhite(col + 1) * 0.65);
-		    sprintf(im.colorTable[0].c_color, "#%04x%04x%04x", bw, bw, bw);
-		}
-		if (col) free(col);
-	    } else {
-		col = im.colorTable[0].c_color;
-		col2 = im.colorTable[1].c_color;
-		if ((col[0] == '#') && (col2[0] == '#')) {
-		    bw = FromColorToBlackAndWhite(col + 1);
-		    bw2 = FromColorToBlackAndWhite(col2 + 1);
-		    if (bw >= bw2) {
-			bw2 = bw2 + ((bw - bw2) * 0.65);
-			sprintf(im.colorTable[1].c_color, "#%04x%04x%04x", bw2, bw2, bw2);
-		    } else {
-			bw = bw + ((bw2 - bw) * 0.65);
-			sprintf (im.colorTable[0].c_color, "#%04x%04x%04x", bw, bw, bw);
-		    }
-		}
-	    }
-	} else {
-	    char e[5];
-	    for (i = 0; i < im.ncolors; i++) {
-		col = im.colorTable[i].c_color;
-		if (col[0] == '#') {
-		    bw = FromColorToBlackAndWhite(col + 1);
-		    /* 
-		    could be					
-		    sprintf(im.colorTable[i].c_color, "#%04x%04x%04x", bw, bw, bw);
-		    Four lower lines is sprintf optimized version
-		     */
-		    sprintf(e, "%04x", bw);
-		    memcpy(col + 1, e, 4);
-		    memcpy(col + 5, e, 4);
-		    memcpy(col + 9, e, 4);
-		}
-	    }
-	}
-    }
-    XpmCreatePixmapFromXpmImage(XtDisplay(w), pm, &im, &bw_pixmap, 0, NULL);
-    XpmFreeXpmImage(&im);
-    return(bw_pixmap);
-}
+  XtReleaseGC ((Widget) lw, lw->label.shadow_GC);
 #endif
+}
 
 /************************************************************************
  *
@@ -1532,7 +1466,8 @@ Redisplay(
 
 #ifdef USE_XFT
     /* it is needed to clear anti-aliased text before draw it again */
-    if ((Lab_IsText (lw) || Lab_IsPixmapAndText(lw)) && (lp->_label != NULL)) 
+    if ((Lab_IsText (lw) || Lab_IsPixmapAndText(lw)) && (lp->_label != NULL)
+		&& lp->TextRect.width > 0 && lp->TextRect.height > 0)
       {
         XClearArea(XtDisplay(lw), XtWindow(lw),
 			lp->TextRect.x,
@@ -1575,7 +1510,7 @@ Redisplay(
 
 	  if (pix_use == XmUNSPECIFIED_PIXMAP)
 #ifdef FIX_1381
-		Pix_insen(lw) = pix_use = ConvertToBW(wid, Pix(lw));
+		Pix_insen(lw) = pix_use = _XmConvertToBW(wid, Pix(lw));
 #else
 		pix_use = Pix(lw);
 #endif
@@ -1632,6 +1567,45 @@ Redisplay(
  	  tmp[_XmOSKeySymToCharacter(lp->mnemonic, NULL, tmp)] = '\0';
 	  underline = XmStringCreate(tmp, lp->mnemonicCharset);
 	  
+#ifdef FIX_1381
+	  if (XtIsSensitive(wid) )
+	  {
+		  /*Draw normal text*/
+		  XmStringDrawUnderline(XtDisplay(lw), XtWindow(lw),
+				  lp->font, lp->_label,
+				  lp->normal_GC,
+				  lp->TextRect.x + lp->StringRect.x,
+				  lp->TextRect.y + lp->StringRect.y,
+				  lp->StringRect.width,
+				  lp->alignment,
+				  XmPrim_layout_direction(lw), NULL,
+				  underline);
+	  }
+	  else
+	  {
+		  /*Draw shadow for insensitive text*/
+		  XmStringDrawUnderline(XtDisplay(lw), XtWindow(lw),
+				  lp->font, lp->_label,
+				  lp->shadow_GC,
+				  lp->TextRect.x+1 + lp->StringRect.x,
+				  lp->TextRect.y+1 + lp->StringRect.y,
+				  lp->StringRect.width,
+				  lp->alignment,
+				  XmPrim_layout_direction(lw), NULL,
+				  underline);
+		  /*Draw insensitive text*/
+		  XmStringDrawUnderline(XtDisplay(lw), XtWindow(lw),
+				  lp->font, lp->_label,
+				  lp->insensitive_GC,
+				  lp->TextRect.x + lp->StringRect.x,
+				  lp->TextRect.y + lp->StringRect.y,
+				  lp->StringRect.width,
+				  lp->alignment,
+				  XmPrim_layout_direction(lw), NULL,
+				  underline);
+
+	  }
+#else
 	  XmStringDrawUnderline(XtDisplay(lw), XtWindow(lw),
 				lp->font, lp->_label,
 				(XtIsSensitive(wid) ? 
@@ -1642,9 +1616,47 @@ Redisplay(
 				lp->alignment,
 				XmPrim_layout_direction(lw), NULL,
 				underline);
+#endif
 	  XmStringFree(underline);
 	}
       else
+#ifdef FIX_1381
+	{
+	  if (XtIsSensitive(wid) )
+	  {
+	  /*Draw normal text*/
+	  XmStringDraw (XtDisplay(lw), XtWindow(lw),
+			  lp->font, lp->_label,
+  			  lp->normal_GC,
+			  lp->TextRect.x + lp->StringRect.x,
+			  lp->TextRect.y + lp->StringRect.y,
+			  lp->StringRect.width,
+			  lp->alignment,
+			  XmPrim_layout_direction(lw), NULL);
+	  }
+	else
+	  {
+	    /*Draw shadow for insensitive text*/
+	    XmStringDraw (XtDisplay(lw), XtWindow(lw),
+			  lp->font, lp->_label,
+			  lp->shadow_GC,
+			  lp->TextRect.x+1 + lp->StringRect.x,
+			  lp->TextRect.y+1 + lp->StringRect.y,
+			  lp->StringRect.width,
+			  lp->alignment,
+			  XmPrim_layout_direction(lw), NULL);
+	    /*Draw insensitive text*/
+	    XmStringDraw (XtDisplay(lw), XtWindow(lw),
+			  lp->font, lp->_label,
+			  lp->insensitive_GC,
+			  lp->TextRect.x + lp->StringRect.x,
+			  lp->TextRect.y + lp->StringRect.y,
+			  lp->StringRect.width,
+			  lp->alignment,
+			  XmPrim_layout_direction(lw), NULL);
+	  }
+	}
+#else
 	XmStringDraw (XtDisplay(lw), XtWindow(lw),
 		       lp->font, lp->_label,
 		       (XtIsSensitive(wid) ? 
@@ -1654,9 +1666,9 @@ Redisplay(
 		       lp->StringRect.width,
 		       lp->alignment,
 		       XmPrim_layout_direction(lw), NULL);
+#endif
 
-#ifdef FIX_1381
-#else
+#ifndef FIX_1381
 #ifdef USE_XFT
       if (!XtIsSensitive(wid))
         {
@@ -1686,6 +1698,36 @@ Redisplay(
 		lw->primitive.shadow_thickness +
 		lp->margin_width) +
 	   lp->margin_left + lp->TextRect.width + lp->margin_right))
+
+#ifdef FIX_1381
+		  if (XtIsSensitive(wid) )
+		  {
+			  /*Draw normal text*/
+			  XmStringDraw (XtDisplay(lw), XtWindow(lw),
+					  lp->font, lp->_acc_text,
+     				   lp->normal_GC,
+					  lp->acc_TextRect.x, lp->acc_TextRect.y,
+					  lp->acc_TextRect.width, XmALIGNMENT_END,
+					  XmPrim_layout_direction(lw), NULL);
+		  }
+		  else
+		  {
+			/*Draw shadow for insensitive text*/
+			XmStringDraw (XtDisplay(lw), XtWindow(lw),
+					  lp->font, lp->_acc_text,
+					   lp->shadow_GC,
+					  lp->acc_TextRect.x+1, lp->acc_TextRect.y+1,
+					  lp->acc_TextRect.width, XmALIGNMENT_END,
+					  XmPrim_layout_direction(lw), NULL);
+			/*Draw insensitive text*/
+			XmStringDraw (XtDisplay(lw), XtWindow(lw),
+					  lp->font, lp->_acc_text,
+					   lp->insensitive_GC,
+					  lp->acc_TextRect.x, lp->acc_TextRect.y,
+					  lp->acc_TextRect.width, XmALIGNMENT_END,
+					  XmPrim_layout_direction(lw), NULL);
+		  }
+#else
 	XmStringDraw (XtDisplay(lw), XtWindow(lw),
 		       lp->font, lp->_acc_text,
 		       (XtIsSensitive(wid) ? 
@@ -1693,6 +1735,7 @@ Redisplay(
 		       lp->acc_TextRect.x, lp->acc_TextRect.y,
 		       lp->acc_TextRect.width, XmALIGNMENT_END,
 		       XmPrim_layout_direction(lw), NULL);
+#endif
     }
   
   /* Redraw the proper highlight  */
@@ -1893,8 +1936,11 @@ SetValues(Widget cw,
     {
       new_w->label.label_type = current->label.label_type;
     }
-
+#ifdef FIX_1484
+  if (!XmRepTypeValidValue(XmRID_PIXMAP_PLACEMENT, new_w->label.pixmap_placement,
+#else
   if (!XmRepTypeValidValue(XmRID_LABEL_TYPE, new_w->label.pixmap_placement,
+#endif
 			   (Widget) new_w))
     {
       new_w->label.pixmap_placement = current->label.pixmap_placement;
