@@ -2920,8 +2920,9 @@ ShowValue(
     if (sw->scale.orientation == XmHORIZONTAL) {
 #if USE_XFT
 	x = scrollbar->core.x
-	    + scrollbar->scrollBar.slider_x;
-	    + scrollbar->scrollBar.slider_width / 2;
+	    + scrollbar->scrollBar.slider_x
+	    + scrollbar->scrollBar.slider_width / 2
+	    - width / 2;
 	if (sw->scale.show_value == XmNEAR_BORDER) 
 	    /*tmp: should store the max */ 
 	    y = scrollbar->core.y - MaxLabelHeight(sw) - height - 3;
@@ -2970,17 +2971,19 @@ ShowValue(
 	    + SLIDER_SIZE(sw) + ((height - SLIDER_SIZE( sw)) / 2) - 3;
 #endif
     }
-    
-#ifndef USE_XFT
+
+#if USE_XFT    
+    sw->scale.show_value_x = x;
+    sw->scale.show_value_y = y + 1;
+#else
     sw->scale.show_value_x = x + width_return.lbearing;
-#endif
     sw->scale.show_value_y = y - height + 1;
+#endif
     
     
     /*  Display the string  */
     XSetClipMask(XtDisplay(sw), sw->scale.foreground_GC, None);
 #if USE_XFT
-    XClearWindow(XtDisplay(sw), XtWindow(sw));
     XmStringDraw(XtDisplay(sw), XtWindow(sw), sw->scale.font_list,
                     tmp_str = XmStringCreateSimple(buffer),
 		    sw->scale.foreground_GC,
