@@ -49,6 +49,8 @@ static char rcsid[] = "$XConsortium: TextStrSo.c /main/14 1996/10/23 16:05:21 cd
 /* (c) Copyright 1989, DIGITAL EQUIPMENT CORPORATION, MAYNARD, MASS. */
 /* (c) Copyright 1987, 1988, 1989, 1990, 1991, 1992 HEWLETT-PACKARD COMPANY */
 
+#define FIX_1320
+
 #include <ctype.h>
 #include <limits.h>
 #include <X11/Xatom.h>
@@ -1238,6 +1240,9 @@ Scan(XmTextSource source,
 	  c = Look(data, position, dir);
 	  if (c && isspace((unsigned char)*c)) {
 	    if (whiteSpace < 0) whiteSpace = position;
+#ifdef FIX_1320
+	    if (*c == '\n') break;
+#endif
 	  } else if (whiteSpace >= 0)
 	    break;
 	  position += ddir;
