@@ -54,6 +54,24 @@
 extern "C" {
 #endif
 
+#define FIX_345
+
+#ifdef FIX_345
+extern Boolean _init_modifiers;
+extern unsigned int NumLockMask;
+extern unsigned int ScrollLockMask;
+
+void _XmInitModifiers (void);
+#define _XmCheckInitModifiers() 						\
+    { 									\
+	if (_init_modifiers) 						\
+	{ 								\
+	    _XmInitModifiers(); 					\
+	    _init_modifiers = FALSE; 					\
+	}								\
+    }
+#endif
+
 #ifndef DEBUG
 # define assert(assert_exp)
 #elif (defined(__STDC__) && !defined(UNIXCPP)) || defined(ANSICPP)
@@ -276,21 +294,19 @@ extern void (*_XtProcessLock)();
 }  /* Close scope of 'extern "C"' declaration which encloses file. */
 #endif
 
-#define FIX_1381
 #define FIX_1396
 
 #ifdef FIX_1381
-#define RGB_GREY_VALUE 128
-#define RGB_GREY_PRESISE 50
 extern Pixel _XmAssignInsensitiveColor(Widget w);
 #endif
 
 #define FIX_1375
-#define FIX_1395 1
-
+#define FIX_1395
 #define FIX_1388
 #define FIX_1398
 #define FIX_1402
+#define FIX_1445
+#define FIX_1474
 
 #endif /* _XmI_h */
 /* DON'T ADD ANYTHING AFTER THIS #endif */
