@@ -98,7 +98,9 @@ extern "C" { /* some 'locale.h' do not have prototypes (sun) */
    ((unsigned int)(unsigned long)(tablist) != XmAS_IS))
 
 #define  FIX_1414
+#define  FIX_1449
 #define  FIX_1444
+#define FIX_1451
 /**********************************************************************
  *	      IMPORTANT NOTE: IMPLEMENTATION OF SHARING
  *
@@ -2935,6 +2937,9 @@ _XmXftDrawCreate(Display *display, Window window)
 	_XmXftDrawCache = (struct _XmXftDrawCacheStruct *)
 		XtRealloc((char *)_XmXftDrawCache,
 		sizeof(struct _XmXftDrawCacheStruct) * _XmXftDrawCacheSize);
+#ifdef FIX_1449
+	memset(_XmXftDrawCache + i, 0, (_XmXftDrawCacheSize - i) * sizeof(*_XmXftDrawCache));
+#endif
 
 	_XmXftDrawCache[i].display = display;
 	_XmXftDrawCache[i].draw = draw;
@@ -3058,11 +3063,17 @@ _XmXftDrawString(Display *display, Window window, XmRendition rend, int bpc,
 	    bg_color.color.blue = xcol.blue;
 	    bg_color.color.alpha = 0xFFFF;
 	}
-
+#ifdef FIX_1451
+        XftDrawRect(draw, &bg_color, x, y - _XmRendXftFont(rend)->ascent,
+	            ext.xOff,
+		    _XmRendXftFont(rend)->ascent +
+		    _XmRendXftFont(rend)->descent);
+#else
         XftDrawRect(draw, &bg_color, x - 10, y - _XmRendXftFont(rend)->ascent - 10,
 	            ext.xOff +20,
 		    _XmRendXftFont(rend)->ascent +
 		    _XmRendXftFont(rend)->descent + 20);
+#endif
     }
 
     if (_XmRendFG(rend) == XmUNSPECIFIED_PIXEL)
