@@ -126,6 +126,7 @@ extern int regex();
 #endif
 
 #define FILE_LIST_BLOCK 64
+#define FIX_1359
 
 typedef struct {   
   unsigned char type ; 
@@ -404,6 +405,15 @@ _XmOSFindPatternPart(String fileSpec)
  *   which contains a wildcard or which is not followed by a '/'.
  ****************/
 {
+#ifdef FIX_1359
+    String ret;
+    
+	if (strlen(fileSpec)) {
+		if ((ret = strrchr(fileSpec, '/')))
+			fileSpec = ret + 1;
+	}
+	return fileSpec;
+#else
   char *          lookAheadPtr = fileSpec;
   char *          maskPtr;
   Boolean         hasWildcards;
@@ -444,6 +454,7 @@ _XmOSFindPatternPart(String fileSpec)
     ++maskPtr;
   
   return(maskPtr);
+#endif
 }
 
 /****************************************************************/
